@@ -1,7 +1,8 @@
 """Testing functions exposed to the user API"""
 import functools
 import warnings
-from typing import Hashable, Set, Union
+from collections.abc import Hashable
+from typing import Union
 
 import numpy as np
 import pandas as pd
@@ -356,7 +357,7 @@ def _assert_dataset_invariants(ds: Dataset, check_default_indexes: bool):
 
     assert type(ds._dims) is dict, ds._dims
     assert all(isinstance(v, int) for v in ds._dims.values()), ds._dims
-    var_dims: Set[Hashable] = set()
+    var_dims: set[Hashable] = set()
     for v in ds._variables.values():
         var_dims.update(v.dims)
     assert ds._dims.keys() == var_dims, (set(ds._dims), var_dims)
